<?php

namespace App\Http\Controllers;
use App\Models\GatewaysModel;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Str;    // for UUID
use Illuminate\Support\Facades\Password;

class GatewayController extends Controller
{
    public function handleForm(Request $request)
    {
        $uid = (string) Str::uuid();
        $gateway = new GatewaysModel();

        $gateway->uid = $uid;
        $gateway->name = $request->input('name');
        $gateway->currency = $request->input('currency');
        $gateway->reserve = $request->input('reserve');
        $gateway->min_amount = $request->input('min_amount');
        $gateway->max_amount = $request->input('max_amount');
        $gateway->exchange_type = $request->input('exchange_type');
        $gateway->include_fee = $request->input('include_fee');
        $gateway->extra_fee = $request->input('extra_fee');
        $gateway->fee = $request->input('fee');
        $gateway->allow_send = $request->input('allow_send');
        $gateway->allow_receive = $request->input('allow_receive');
        $gateway->default_send = $request->input('default_send');
        $gateway->default_receive = $request->input('default_receive');
        $gateway->allow_payouts = $request->input('allow_payouts');
        $gateway->a_field_1 = $request->input('a_field_1');
        $gateway->a_field_2 = $request->input('a_field_2');
        $gateway->a_field_3 = $request->input('a_field_3');
        $gateway->a_field_4 = $request->input('a_field_4');
        $gateway->a_field_5 = $request->input('a_field_5');
        $gateway->a_field_6 = $request->input('a_field_6');
        $gateway->a_field_7 = $request->input('a_field_7');
        $gateway->a_field_8 = $request->input('a_field_8');
        $gateway->a_field_9 = $request->input('a_field_9');
        $gateway->a_field_10 = $request->input('a_field_10');
        $gateway->status = $request->input('status');
        $gateway->external_gateway = $request->input('external_gateway');
        $gateway->require_login = $request->input('require_login');
        $gateway->require_email_verify = $request->input('require_email_verify');
        $gateway->require_mobile_verify = $request->input('require_mobile_verify');
        $gateway->require_document_verify = $request->input('require_document_verify');
        $gateway->is_crypto = $request->input('is_crypto');
        $gateway->merchant_source = $request->input('merchant_source');
        
        $gateway->created_at = time();  
        $gateway->updated_at = time();  
        
        if ($request->hasFile('external_icon')) {
            $external_icon = $request->file('external_icon');
            $iconName = time() . '.' . $external_icon->getClientOriginalExtension();

            $external_icon->storeAs('public/currency_icons', $iconName);
            $gateway->external_icon = $iconName; 
        } 
        
        if($request->input('exchange_type') != '3'){
            // Loop through all the fields and store them as JSON objects
            for ($i = 1; $i <= 10; $i++) {
                $fieldName = 'a_field_' . $i;
                if ($request->has($fieldName)) {
                    $gateway->$fieldName = json_decode($request->input($fieldName));
                }
            }
        }

        $return = $gateway->save();

        if ($return) {
            return response()->json(['status' => 'success', 'message' => 'Gateway added successfully'], 201);
        } else {
            return response()->json(['status' => 'error', 'message' => 'Failed to add gateway.'], 500);
        }
    }

    public function displayGateway()
    {
        $manual_payment = GatewaysModel::all();
        return view('admin.pages.gateways.add_manual_payment', compact('manual_payment'));
    }

    public function editGateway($id)
    {
        $gateway = GatewaysModel::find($id);
        if (!$gateway) {
            return redirect('/admin/gateways')->with('error', 'Gateway not found');
        }
        return view('admin.pages.gateways.add_merchant', compact('gateway'));
    }

    public function updateGateway(Request $request, $id)
    {
        $gateway = GatewaysModel::find($id);

        if (!$gateway) {
            return redirect('/admin/gateways/add_merchant')->with('error', 'Gateway not found');
        }

        $gateway->name = $request->name;
        $gateway->currency = $request->currency;
        $gateway->min_amount = $request->min_amount;
        $gateway->max_amount = $request->max_amount;
        $gateway->reserve = $request->reserve;
        $gateway->fee = $request->fee;
        $gateway->include_fee = $request->include_fee;
        $gateway->extra_fee = $request->extra_fee;
        $gateway->allow_send = $request->allow_send;
        $gateway->is_crypto = $request->is_crypto;
        $gateway->require_login = $request->require_login;
        $gateway->require_email_verify = $request->require_email_verify;
        $gateway->require_document_verify = $request->require_document_verify;
        $gateway->require_mobile_verify = $request->require_mobile_verify;
        $gateway->external_icon =  $request->external_icon;
    
        $gateway->save();

        return response()->json(['message' => 'Gateway updated successfully.'], 200);
    }



    public function deleteGateway(Request $request)
    {
        $payment = GatewaysModel::find($request->id);
        if ($payment){
            $payment->delete();
            return response()->json(['success' => true, 'message' => 'Gateway deleted successfully']);
        }
        return response()->json(['success' => false, 'message' => 'Gateway not found']);
    }

    public function updateGatewayStatus(Request $request)
    {
        $merchant = GatewaysModel::find($request->id);
        if ($merchant) {
            $merchant->status = $request->status; // Update the status field
            $merchant->save(); // Save the changes to the database
    
            return response()->json(['success' => true]); // Return success response
        }
    
        return response()->json(['success' => false, 'message' => 'Merchant not found']);
    }

    public function showGateways()
    {
        $gateways = GatewaysModel::all();
        return view('admin.pages.gateways', compact('gateways'));
    }


}
