<?php

namespace App\Http\Controllers;
use App\Models\AddManualPaymentFormSubmission;
use App\Models\GatewaysModel;
use App\Models\ExchangeFormModel;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Str;    // for UUID
use Illuminate\Support\Facades\Password;
use App\Http\Controllers\CurrencyConversionController;  


class HomeController extends Controller
{
    public function showPage(Request $request)
    {
        if ($request->has('action') && $request->input('action') === 'getCurrencyIcon') {
            $currency = $request->input('currency');
            $currencyData = GatewaysModel::where('currency', $currency)->first();
            if ($currencyData) {
                return response()->json(['icon_path' => asset('storage/currency_icons/' . $currencyData->external_icon)]);
            }
            return response()->json(['icon_path' => asset('storage/currency_icons/default_img.png')], 404);
        }

        if ($request->input('action') === 'getCurrencyLimits') {
            $currency = $request->input('currency');
            $currencyData = GatewaysModel::where('currency', $currency)->first();
            
            if ($currencyData) {
                return response()->json([
                    'min_amount' => $currencyData->min_amount,
                    'max_amount' => $currencyData->max_amount,
                    'currency_fee' => $currencyData->fee,
                    'a_field_1' => $currencyData->a_field_1,
                    'a_field_2' => $currencyData->a_field_2,
                    'a_field_3' => $currencyData->a_field_3,
                    'a_field_4' => $currencyData->a_field_4,
                    'a_field_5' => $currencyData->a_field_5,
                    'a_field_6' => $currencyData->a_field_6,
                    'a_field_7' => $currencyData->a_field_7,
                    'a_field_8' => $currencyData->a_field_8,
                    'a_field_9' => $currencyData->a_field_9,
                    'a_field_10' => $currencyData->a_field_10,
                ]); 
            }
            return response()->json(['error' => 'Currency not found'], 404);
        }

        $currencies = $this->showCurrencies(); 
        
        $currencyConversionController = new CurrencyConversionController();
        $currencyRates = $currencyConversionController->fetchCurrencyRates();

        return view('frontend.pages.home', compact('currencies', 'currencyRates'));
    }

    public function getCurrencyLimits(Request $request)
    {
        $currency = $request->input('currency');
        $currencyData = GatewaysModel::where('currency', $currency)->first();
        if ($currencyData) {
            return response()->json([
                'min_amount' => $currencyData->min_amount,
                'max_amount' => $currencyData->max_amount,
                'currency_fee' => $currencyData->fee,
            ]);
        }
        return response()->json(['error' => 'Currency not found'], 404);
    }


    public function showCurrencies()
    {
        $currencies = GatewaysModel::all();
        // return view('frontend.pages.home', compact('currencies'));
        
        return $currencies;
    }

    public function fieldValues(Request $request)
    {
        $exchange = new ExchangeFormModel();

        $uid = (string) Str::uuid();
        $exchange->uid = $uid;
        $exchange->amount_send = $request->give_amount;
        $exchange->amount_receive = $request->take_amount;
        $exchange->u_field_1 = $request->a_field_1;
        $exchange->u_field_2 = $request->a_field_2;
        $exchange->u_field_3 = $request->a_field_3;
        $exchange->u_field_4 = $request->a_field_4;
        $exchange->u_field_5 = $request->a_field_5;
        $exchange->u_field_6 = $request->a_field_6;
        $exchange->u_field_7 = $request->a_field_7;
        $exchange->u_field_8 = $request->a_field_8;
        $exchange->u_field_9 = $request->a_field_9;
        $exchange->u_field_10 = $request->a_field_10;
        $exchange->agree_with_rules = $request->agree_with_rules;  
        $exchange->agree_with_KYC_policy = $request->agree_with_KYC_policy;

        // $exchange->give_currency_minimum_amount = $request->give_currency_minimum_amount;
        // $exchange->give_currency_maximum_amount = $request->give_currency_maximum_amount;
        // $exchange->take_currency_minimum_amount = $request->take_currency_minimum_amount;
        // $exchange->take_currency_maximum_amount = $request->take_currency_maximum_amount;
        // $exchange->rate = $request->rate;
        // $exchange->fee = $request->fee;

        // $fields_values = $request->except(['agree_with_rules', 'agree_with_KYC_policy', '_token']);
        // $exchange->fields_values = json_encode($fields_values);

        $return = $exchange->save();

        if ($return) {
            return response()->json(['status' => 'success', 'message' => 'exchange details added successfully'], 201);
        } else {
            return response()->json(['status' => 'error', 'message' => 'Failed to add exchange details.'], 500);
        }
    }

    public function fetchDetails()
    {
        $details = GatewaysModel::all();
        return view('frontend.pages.home', compact('details'));
    }
}
