<?php

namespace App\Http\Controllers;
use App\Models\AddManualPaymentFormSubmission;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Str;    // for UUID
use Illuminate\Support\Facades\Password;

class ManualPaymentController extends Controller
{
    public function handleForm(Request $request)
    {
        // $validatedData = $request->validate([
        //     'gateway' => 'required|string|max:255',
        //     'currency' => 'required|string|max:255',
        //     'currency_code' => 'required|string|max:255',
        //     'minimum_amount' => 'required|numeric|min:0',
        //     'maximum_amount' => 'required|numeric|min:0',
        //     'reserve' => 'required|numeric|min:0',
        //     'fee' => 'required|numeric|min:0',
        //     'include_extra_fee' => 'nullable|boolean',
        //     'extra_fee' => $request->has('include_extra_fee') ? 'required|numeric|min:0' : 'nullable',
        //     'allow_customers_to_send_money' => 'nullable|boolean',
        //     'is_crypto_currency' => 'nullable|boolean',
        //     'require_user_to_login' => 'nullable|boolean',
        //     'require_user_to_verify_email' => 'nullable|boolean',
        //     'require_user_to_verify_personal_documents' => 'nullable|boolean',
        //     'require_user_to_verify_mobile_number' => 'nullable|boolean',
        //      'icon' => 'required|string|max:255',
        // ]);

        $addManualPaymentFormSubmission = new AddManualPaymentFormSubmission();

        if ($request->hasFile('icon')) {
            $icon = $request->file('icon');
            $iconName = time() . '.' . $icon->getClientOriginalExtension();

            $icon->storeAs('public/currency_icons', $iconName);
            $addManualPaymentFormSubmission->icon = $iconName; 
        } 

        $uid = (string) Str::uuid();  // Generate a UUID

        $addManualPaymentFormSubmission->uid = $uid;
        $addManualPaymentFormSubmission->gateway = $request->gateway;
        $addManualPaymentFormSubmission->currency = $request->currency;
        $addManualPaymentFormSubmission->currency_code = $request->currency_code;
        $addManualPaymentFormSubmission->minimum_amount = $request->minimum_amount;
        $addManualPaymentFormSubmission->maximum_amount = $request->maximum_amount;
        $addManualPaymentFormSubmission->reserve = $request->reserve;
        $addManualPaymentFormSubmission->fee = $request->fee;
        $addManualPaymentFormSubmission->include_extra_fee = $request->include_extra_fee;  // Use merged data
        $addManualPaymentFormSubmission->extra_fee = $request->extra_fee;
        $addManualPaymentFormSubmission->allow_customers_to_send_money = $request->allow_customers_to_send_money;  // Use merged data
        $addManualPaymentFormSubmission->is_crypto_currency = $request->is_crypto_currency;  // Use merged data
        $addManualPaymentFormSubmission->require_user_to_login = $request->require_user_to_login;  // Use merged data
        $addManualPaymentFormSubmission->require_user_to_verify_email = $request->require_user_to_verify_email;  // Use merged data
        $addManualPaymentFormSubmission->require_user_to_verify_personal_documents = $request->require_user_to_verify_personal_documents;  // Use merged data
        $addManualPaymentFormSubmission->require_user_to_verify_mobile_number = $request->require_user_to_verify_mobile_number;
        $addManualPaymentFormSubmission->created_at = time();  
        $addManualPaymentFormSubmission->updated_at = time();  

        $fieldNames = $request->input('field_name');  // Expected to be an array or JSON string
        $fieldValues = $request->input('field_value');  // Expected to be an array or JSON string

        $addManualPaymentFormSubmission->field_name = json_decode($fieldNames);  // decode JSON to array
        $addManualPaymentFormSubmission->field_value = json_decode($fieldValues); // decode JSON to array        

        $return = $addManualPaymentFormSubmission->save();

        if ($return) {
            return response()->json(['status' => 'success', 'message' => 'Manual Payment added successfully'], 201);
        } else {
            return response()->json(['status' => 'error', 'message' => 'Failed to add manual payment.'], 500);
        }
    }

    public function showOptions()
    {
        $ms = AddManualPaymentFormSubmission::all();
        return view('admin.pages.gateways.add_merchant', compact('ms'));
    }

    public function displayManualPayment()
    {
        $manual_payment = AddManualPaymentFormSubmission::all();
        return view('admin.pages.gateways.manual_payment_details', compact('manual_payment'));
    }

    public function updateStatus(Request $request)
    {
        $payment = AddManualPaymentFormSubmission::find($request->id);
        if ($payment) {
            $payment->status = $request->status; // Update the status field
            $payment->save(); // Save the changes to the database
    
            return response()->json(['success' => true]); // Return success response
        }
    
        return response()->json(['success' => false, 'message' => 'Manual payment not found.']);
    }

    public function edit($id)
    {
        $manual_payment = AddManualPaymentFormSubmission::find($id);
        if (!$manual_payment) {
            return redirect('/admin/gateways/manual_payment_details')->with('error', 'Manual Payment not found');
        }
        return view('admin.pages.gateways.add_manual_payment', compact('manual_payment'));
    }

    public function update(Request $request, $id)
    {
        $payment = AddManualPaymentFormSubmission::find($id);

        if (!$payment) {
            return redirect('/admin/gateways/manual_payment_details')->with('error', 'Payment not found');
        }

        $payment->gateway = $request->gateway;
        $payment->currency = $request->currency;
        $payment->minimum_amount = $request->minimum_amount;
        $payment->maximum_amount = $request->maximum_amount;
        $payment->reserve = $request->reserve;
        $payment->fee = $request->fee;
        $payment->include_extra_fee = $request->include_extra_fee;
        $payment->extra_fee = $request->extra_fee;
        $payment->allow_customers_to_send_money = $request->allow_customers_to_send_money;
        $payment->is_crypto_currency = $request->is_crypto_currency;
        $payment->require_user_to_login = $request->require_user_to_login;
        $payment->require_user_to_verify_email = $request->require_user_to_verify_email;
        $payment->require_user_to_verify_personal_documents = $request->require_user_to_verify_personal_documents;
        $payment->require_user_to_verify_mobile_number = $request->require_user_to_verify_mobile_number;
        $payment->icon = $request->icon;
    
        $payment->save();

        return redirect('/admin/gateways/manual_payment_details')->with('success', 'Manual Payment updated successfully');
    }

    public function delete(Request $request)
    {
        $payment = AddManualPaymentFormSubmission::find($request->id);
        if ($payment){
            $payment->delete();
            return response()->json(['success' => true, 'message' => 'Manual Payment deleted successfully']);
        }
        return response()->json(['success' => false, 'message' => 'Manual Payment not found']);
    }



}