<?php

namespace App\Http\Controllers;
use App\Models\GatewaysModel;
use App\Models\AddManualPaymentFormSubmission;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Str;    // for UUID
use Illuminate\Support\Facades\Password;

class MerchantController extends Controller
{
    public function handleForm(Request $request)
    {
        $uid = (string) Str::uuid();  // Generate a UUID

        $addMerchantFormSubmission = new AddMerchantFormSubmission();

        $addMerchantFormSubmission->uid = $uid;
        $addMerchantFormSubmission->select_merchant = $request->select_merchant;
        $addMerchantFormSubmission->currency = $request->currency;
        $addMerchantFormSubmission->minimum_amount = $request->minimum_amount;
        $addMerchantFormSubmission->maximum_amount = $request->maximum_amount;
        $addMerchantFormSubmission->reserve = $request->reserve;
        $addMerchantFormSubmission->fee = $request->fee;
        $addMerchantFormSubmission->include_extra_fee = $request->include_extra_fee;  // Use merged data
        $addMerchantFormSubmission->extra_fee = $request->extra_fee;
        $addMerchantFormSubmission->allow_customers_to_send_money = $request->allow_customers_to_send_money;  // Use merged data
        $addMerchantFormSubmission->require_user_to_login = $request->require_user_to_login;  // Use merged data
        $addMerchantFormSubmission->require_user_to_verify_email = $request->require_user_to_verify_email;  // Use merged data
        $addMerchantFormSubmission->require_user_to_verify_documents = $request->require_user_to_verify_documents;  // Use merged data
        $addMerchantFormSubmission->require_user_to_verify_mobile_number = $request->require_user_to_verify_mobile_number;  // Use merged data
        $addMerchantFormSubmission->created_at = time();  
        $addMerchantFormSubmission->updated_at = time();  

        $return = $addMerchantFormSubmission->save();

        if ($return) {
            return response()->json(['status' => 'success', 'message' => 'Merchant added successfully'], 201);
        } else {
            return response()->json(['status' => 'error', 'message' => 'Failed to add merchant.'], 500);
        }
    }

    public function showGateways()
    {
        $merchants = AddMerchantFormSubmission::all();
        return view('admin/pages/gateways', compact('merchants'));
    }

    public function updateStatus(Request $request)
    {
        $merchant = AddMerchantFormSubmission::find($request->id);
        if ($merchant) {
            $merchant->status = $request->status; // Update the status field
            $merchant->save(); // Save the changes to the database
    
            return response()->json(['success' => true]); // Return success response
        }
    
        return response()->json(['success' => false, 'message' => 'Merchant not found']);
    }

    public function edit($id)
    {
        $merchant = AddMerchantFormSubmission::find($id);
        $ms = AddManualPaymentFormSubmission::all();
        if (!$merchant) {
            return redirect()->route('merchant.index')->with('error', 'Merchant not found');
        }
        return view('admin.pages.gateways.add_merchant', compact('merchant','ms'));
    }

    public function update(Request $request, $id)
    {
        $merchant = AddMerchantFormSubmission::find($id);

        if (!$merchant) {
            return redirect('/admin/gateways')->with('error', 'Merchant not found');
        }

        $merchant->select_merchant = $request->select_merchant;
        $merchant->currency = $request->currency;
        $merchant->minimum_amount = $request->minimum_amount;
        $merchant->maximum_amount = $request->maximum_amount;
        $merchant->reserve = $request->reserve;
        $merchant->fee = $request->fee;
        $merchant->include_extra_fee = $request->include_extra_fee;
        $merchant->extra_fee = $request->extra_fee;
        $merchant->allow_customers_to_send_money = $request->allow_customers_to_send_money;
        $merchant->require_user_to_login = $request->require_user_to_login;
        $merchant->require_user_to_verify_email = $request->require_user_to_verify_email;
        $merchant->require_user_to_verify_documents = $request->require_user_to_verify_documents;
        $merchant->require_user_to_verify_mobile_number = $request->require_user_to_verify_mobile_number;
    
        $merchant->save();

        return redirect('/admin/gateways/add_merchant')->with('success', 'Merchant updated successfully');
    }

    public function delete(Request $request)
    {
        $merchant = AddMerchantFormSubmission::find($request->id);
        if ($merchant){
            $merchant->delete();
            return response()->json(['success' => true, 'message' => 'Merchant deleted successfully']);
        }
        return response()->json(['success' => false, 'message' => 'Merchant not found']);
    }


}
