<?php

namespace App\Http\Controllers;
use App\Models\SettingsModel;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Str;    // for UUID
use Illuminate\Support\Facades\Password;

class SettingsController extends Controller
{
    public function update(Request $request, $id)
    {
        $settings = SettingsModel::find($id);
        
        if ($request->hasFile('logos')) {
            $logos = $request->file('logos');  
            $logoNames = $settings->brands_logo ? json_decode($settings->brands_logo, true) : [];
        
            foreach ($logos as $logo) {
                $logoName = 'logo_' . time() . '_' . uniqid() . '.' . $logo->getClientOriginalExtension();
                $logo->storeAs('public/brands_logo', $logoName);  
                $logoNames[] = $logoName;  
            }
            $settings->brands_logo = json_encode($logoNames);
        }

        if ($request->hasFile('logo')) {
            $logo = $request->file('logo');
            $logoName = 'logo_' . time() . '.' . $logo->getClientOriginalExtension();
            $logo->storeAs('public/brands_logo', $logoName); 
            $settings->logo = $logoName; 
        }
        
        if ($request->hasFile('favicon')) {
            $favicon = $request->file('favicon');
            $faviconName = 'favicon_' . time() . '.' . $favicon->getClientOriginalExtension();
            $favicon->storeAs('public/brands_logo', $faviconName); 
            $settings->favicon = $faviconName; 
        }

        $settings->title = $request->title;
        $settings->meta_title = $request->meta_title;
        $settings->meta_description =  $request->input('meta_description', '');
        $settings->meta_keywords = $request->input('meta_keywords', '');
        $settings->site_name = $request->site_name;
        $settings->site_url = $request->site_url;
        $settings->info_email = $request->info_email;
        $settings->support_email = $request->support_email;
        $settings->copyright = $request->copyright;
        $settings->skype = $request->skype;
        $settings->whatsapp = $request->whatsapp;
        $settings->referral_commission = $request->referral_commission;
        $settings->require_user_to_login = $request->require_user_to_login;  
        $settings->require_user_to_upload_documents = $request->has('require_user_to_upload_documents') ? 'true' : 'false';
        $settings->require_user_to_verify_email = $request->has('require_user_to_verify_email') ? 'true' : 'false';  
        $settings->require_user_to_verify_mobile_number = $request->has('require_user_to_verify_mobile_number') ? 'true' : 'false';
        $settings->nexmo_api_key = $request->nexmo_api_key; 
        $settings->nexmo_api_secret = $request->nexmo_api_secret;
        $settings->work_time_start = $request->input('work_time_start', '');
        $settings->work_time_end = $request->input('work_time_end', '');
        $settings->work_time_gmt_zone = $request->input('work_time_gmt_zone', '');
        $settings->footer_short_info = $request->input('footer_short_info', '');
        $settings->location = $request->location;
        $settings->created_at = time();  
        $settings->updated_at = time();  
        $socialMediaLinks = $request->social_media_links;
        if ($socialMediaLinks) {
            $settings->social_media_links = $socialMediaLinks;
        }
        $return = $settings->save();

        if ($return) {
            return response()->json(['status' => 'success', 'message' => 'Settings updated successfully'], 201);
        } else {
            return response()->json(['status' => 'error', 'message' => 'Failed to update Settings'], 500);
        }
    }

    public function deleteLogo(Request $request)
    {
        $settings = SettingsModel::first();  
        if (!$settings || !$request->has('logoKey')) {
            return response()->json(['status' => 'error', 'message' => 'Logo not found'], 404);
        }
        $logoKey = $request->logoKey;
        $logoList = $settings->brands_logo ? json_decode($settings->brands_logo, true) : [];
        if (isset($logoList[$logoKey])) {
            \Storage::delete('public/brands_logo/' . $logoList[$logoKey]);
            unset($logoList[$logoKey]);
            $settings->brands_logo = json_encode(array_values($logoList));
            $settings->save();
            return response()->json(['status' => 'success', 'message' => 'Logo deleted successfully']);
        }
        return response()->json(['status' => 'error', 'message' => 'Logo not found'], 404);
    }


    public function showSocialMediaLinks(Request $request)
    {
        $settings = Settings::first(); 
        $socialMediaLinks = json_decode($settings->social_media_links, true); 
        return view('admin.pages.settings', compact('settings', 'socialMediaLinks'));
    }

    public function displayInfo()
    {
        $settings = Settings::all();
        return view('frontend.layouts.footer', compact('settings'));
    }



    
}

