<?php
namespace App\Http\Controllers;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Str;    //for UUID
use Illuminate\Support\Facades\Password;
use Illuminate\Support\Facades\Mail;


class UserController extends Controller
{
    public function showRegistrationForm()
    {
        return view('frontend.pages.register');
    }
    
    public function registerUser(Request $request)
    {
        $request->validate([
            'username'=>'required',
            'email'=>'required',
            'password'=>'required|min:8',
        ]);
       
        $user = new User();
        $user->uid = (string) Str::uuid();  // Generates a unique UUID       
        $user->username = $request->username;
        $user->email = $request->email; 
        $user->mobile_number = $request->mobile_number; 
        $user->password = $request->password;
        $user->user_type = 'superadmin';
        $user->created_at = time();
        $user->updated_at = time();

        $result = $user->save();
        if ($user->save()) {
            return response()->json(['status' => 'success', 'message' => 'User registered successfully.'], 201);
        } else {
            return response()->json(['status' => 'error', 'message' => 'Failed to register user.'], 500);
        }
    }

    public function showLoginForm()
    {
        return view('frontend.pages.login');
    }

    public function login(Request $request)
    {
        if (Auth::attempt(['email' => $request->email, 'password' => $request->password])) {
            $user = Auth::user();
            if ($request->ajax()) {
                return response()->json(['status' => 'success', 'message' => 'Logged in successfully.']);
            }
        }
        if ($request->ajax()) {
            return response()->json(['status' => 'error', 'message' => 'Invalid credentials.'], 401);
        }
        return response()->json(['status' => 'error', 'message' => 'Invalid credentials.'], 500);
    }

    public function logout(Request $request)
    {
        $request->session()->forget(['email', 'username']);

        Auth::logout();
        $request->session()->invalidate();
        $request->session()->regenerateToken();
        return redirect()->route('login')->with('message', 'Successfully logged out.');
    }

    public function showUser()
    {
        $users = User::all();
        return view('admin/pages/users', compact('users'));
    }

    public function updateStatus(Request $request)
    {
        $user = User::find($request->id);
        if ($user) {
            $user->status = $request->status; // Update the status field
            $user->save(); // Save the changes to the database
            return response()->json(['success' => true]); // Return success response
        }
        return response()->json(['success' => false, 'message' => 'User not found.']);
    }

    // forgot password functionality
    public function showLinkRequestForm()
    {
        return view('frontend.pages.forgot_password');
    }

    public function sendResetLinkEmail(Request $request)
    {
        $request->validate(['email' => 'required|email']);
        $response = Password::sendResetLink(
            $request->only('email')
        );
        return $response == Password::RESET_LINK_SENT
            ? back()->with('status', 'We have emailed your password reset link!')
            : back()->withErrors(['email' => 'We could not find a user with that email address.']);
    }
    
    public function showResetForm(Request $request, $token = null)
    {
        return view('frontend/pages/reset_password')->with(['token' => $token, 'email' => $request->email]);
    }

    public function reset(Request $request)
    {
        // $request->validate([
        //     'email' => 'required|email',
        //     'password' => 'required|confirmed|min:8',
        //     'token' => 'required'
        // ]);

        $response = Password::reset(
            $request->only('email', 'password', 'password_confirmation', 'token'),
            function ($user) use ($request) {
                $user->forceFill([
                    'password' => Hash::make($request->password),
                ])->save();
            }
        );

        return $response == Password::PASSWORD_RESET
            ? redirect()->route('login')->with('status', 'Your password has been reset!')
            : back()->withErrors(['email' => [trans($response)]]);
    }

    

}
